@@ -123,7 +123,7 @@ jthread(void *args)
 
     while (snd_pcm_readi(pcm_handle, data, frames) < 0) {
       snd_pcm_prepare(pcm_handle);
-#ifdef XDEBUG
+#ifdef DEBUG_ALSA
       fprintf(stderr, "[!] %s: Buffer overrun\n", __FILE__);
 #endif
     }
