@@ -72,12 +72,12 @@ process(jack_nframes_t nframes, void *arg)
     }
 
     chunk++;
-#ifdef XDEBUG
+#ifdef DEBUG_JACKAUDIO
     printf("[i] JACK: chunk= %d\n", chunk);
 #endif
 
     if (chunk == chunks) {
-#ifdef XDEBUG
+#ifdef DEBUG_JACKAUDIO
       printf("[i] JACK: setting input, idx= %d\n", idx);
 #endif
       pthread_mutex_lock(&ctx->input->mutex);
