@@ -23,7 +23,6 @@
 #include <pulse/error.h>
 
 
-u_long id = 1228051674;
 u_long options = BEQ_THREAD;
 
 static uint32_t insize, buff_size;
@@ -55,7 +54,7 @@ create(Context_t *ctx)
                        NULL,               /* Buffering attributes. */
                        &error              /* Error code. */
                       );
-  if (pa_s == NULL)
+  if (NULL == pa_s)
     xerror(__FILE__": pa_simple_new() failed: %s\n",
            pa_strerror(error));
 
