@@ -23,7 +23,7 @@
 
 uint32_t version = 0;
 u_long options = BE_GFX;
-u_long mode = OVERLAY;
+enum LayerMode mode = LM_OVERLAY;
 
 char dname[] = "GLCube";
 char desc[] = "OpenGL cube";
