@@ -22,7 +22,7 @@
 
 uint32_t version = 0;
 u_long options = BE_CLEAN|BEQ_FIRST;
-u_long mode = NORMAL;
+enum LayerMode mode = LM_NORMAL;
 char desc[] = "Clears the screen";
 char dname[] = "Clear";
 
