@@ -24,7 +24,7 @@ char dname[] = "Color cycle";
 
 uint32_t version = 0;
 u_long options = BEQ_COLORMAP | BEQ_NORANDOM;
-u_long mode = NONE;
+enum LayerMode mode = LM_NONE;
 char desc[] = "Cycle the current colormap";
 
 
