@@ -113,7 +113,7 @@
 /* it's pseudo-3d */
 uint32_t version = 0;
 u_long options = BE_GFX;
-u_long mode = OVERLAY;
+enum LayerMode mode = LM_OVERLAY;
 char desc[] = "Flow effect";
 char dname[] = "Flow";
 
@@ -468,7 +468,7 @@ on_switch_on(Context_t *ctx)
 int8_t
 create(Context_t *ctx)
 {
-  changeme = b_timer_new();
+  changeme = b_timer_new("flow");
   on_switch_on(ctx);
 
   return 1;
