@@ -23,7 +23,7 @@
 uint32_t version = 0;
 u_long options = BE_DISPLACE|BE_LENS;
 char dname[] = "Hodge";
-u_long mode = XOR;
+enum LayerMode mode = LM_XOR;
 char desc[] = "Cellular automaton";
 
 /*
