@@ -23,7 +23,7 @@
 
 uint32_t version = 0;
 u_long options = BE_GFX|BEQ_IMAGE;
-u_long mode = NORMAL;
+enum LayerMode mode = LM_NORMAL;
 char desc[] = "Random image squares";
 char dname[] = "Image squares";
 
