@@ -177,7 +177,7 @@ VectorField_new(const u_char nb_fct, t_complex (*fct)(t_complex, guint32, gint32
 void
 VectorField_delete(VectorField_t *vf)
 {
-  assert(vf != NULL);
+  assert(NULL != vf);
 
   g_free(vf->vector_field->vector);
   g_free(vf->vector_field);
