@@ -66,7 +66,7 @@ set_parameters(const Context_t *ctx, const json_t *in_parameters)
 {
   plugin_parameter_parse_int_range(in_parameters, BPP_EFFECT, &effect, 0, NB_FCT-1);
   if (plugin_parameter_parse_int_range(in_parameters, BPP_DELAY, &delay, 1, 60) & PLUGIN_PARAMETER_CHANGED) {
-    b_timer_restart(timer);
+    b_timer_start(timer);
   }
 
   if (plugin_parameter_parse_string_list_as_int_range(in_parameters, BPP_MODE, MODE_NB, mode_list, (int *)&mode, 0, MODE_NB-1) & PLUGIN_PARAMETER_CHANGED) {
@@ -199,7 +199,7 @@ int8_t
 create(Context_t *ctx)
 {
   vf = VectorField_new(NB_FCT, &fct);
-  timer = b_timer_new();
+  timer = b_timer_new("infinity");
   shuffler = Shuffler_new(NB_FCT);
 
   mode = MODE_RANDOM;
