@@ -21,16 +21,18 @@
 
 
 uint32_t version = 0;
-u_long options = BE_GFX|BEQ_UNIQUE;
+u_long options = BE_GFX|BEQ_UNIQUE|BEQ_NORANDOM;
 char desc[] = "Cellular automaton";
 char dname[] = "Life";
 
+
 void
 run(Context_t *ctx)
 {
   u_short i, j;
   const Buffer8_t *src = active_buffer(ctx);
   Buffer8_t *dst = passive_buffer(ctx);
+  Pixel_t c;
 
   for (j = 0; j < HEIGHT; j++)
     for (i = 0; i < WIDTH; i++) {
@@ -57,24 +59,15 @@ run(Context_t *ctx)
       LIFE(i+1, j+0);
       LIFE(i+1, j+1);
 
-      /* A dead cell with exactly three or six live
-      neighbors becomes a live cell (birth). */
-      if (!get_pixel_nc(src, i, j) && (count == 3)) {
-        set_pixel_nc(dst, i, j, b_rand_int_range(200, 255));
+      if ((c = get_pixel_nc(src, i, j)) && ((count == 2) || (count == 3))) {
+        // Any live cell with two or three live neighbours survives.
+        set_pixel_nc(dst, i, j, c);
       } else {
-        /* A live cell with two or three live neighbors
-           stays alive (survival). */
-        Pixel_t c;
-        if ((c = get_pixel_nc(src, i, j))
-            && ((count == 2) || (count == 3))) {
-          if (!--c) {
-            c = 255;
-          }
-          set_pixel_nc(dst, i, j, c);
-        } else
-          /* In all other cases, a cell dies or
-             remains dead (overcrowding or loneliness) */
-        {
+        // Any dead cell with three live neighbours becomes a live cell.
+        if (!get_pixel_nc(src, i, j) && (count == 3)) {
+          set_pixel_nc(dst, i, j, b_rand_int_range(128, 255));
+        } else {
+          // All other live cells die in the next generation. Similarly, all other dead cells stay dead.
           set_pixel_nc(dst, i, j, 0);
         }
       }
