@@ -20,11 +20,10 @@
 #include "context.h"
 
 
-u_long id = 1169583898;
 uint32_t version = 0;
 u_long options = BE_LENS;
 char desc[] = "Mosaic effect";
-
+char dname[] = "Mosaic";
 
 enum Modes { EXPAND=1, SHRINK=-1 }; /* initialization values may be useless */
 static enum Modes mode = EXPAND;
