@@ -20,10 +20,10 @@
 
 #include "context.h"
 
-u_long id = 957202985;
 uint32_t version = 0;
 u_long options = BE_WARP | BE_LENS;
 char desc[] = "Ripple effect";
+char dname[] = "Ripple";
 
 #define RIPPLE_SIZE_MAX 50
 
