@@ -28,7 +28,7 @@
 
 uint32_t version = 0;
 u_long options = BE_GFX | BE_SFX2D;
-u_long mode = OVERLAY;
+enum LayerMode mode = LM_OVERLAY;
 char dname[] = "Rotors freq";
 char desc[] = "Rotors effect depending on frequency";
 
