@@ -21,7 +21,6 @@
 #include "infinity.h"
 #include "parameters.h"
 
-u_long id = 1190050161;
 uint32_t version = 0;
 u_long options = BE_DISPLACE;
 char dname[] = "Speaker";
@@ -33,7 +32,7 @@ char desc[] = "Infinity effect which reacts to volume";
 static VectorField_t *vf = NULL;
 
 
-static float volume_scale = 0;
+static double volume_scale = 0;
 
 json_t *
 get_parameters()
@@ -46,16 +45,18 @@ get_parameters()
 
 
 void
-set_parameters(const json_t *in_parameters)
+set_parameters(const Context_t *ctx, const json_t *in_parameters)
 {
-  plugin_parameter_parse_float_range(in_parameters, BPP_VOLUME_SCALE, &volume_scale, 0, 100);
+  plugin_parameter_parse_double_range(in_parameters, BPP_VOLUME_SCALE, &volume_scale, 0, 100);
 }
 
 
 json_t *
-parameters(const json_t *in_parameters)
+parameters(const Context_t *ctx, const json_t *in_parameters)
 {
-  set_parameters(in_parameters);
+  if (NULL != in_parameters) {
+    set_parameters(ctx, in_parameters);
+  }
 
   return get_parameters();
 }
@@ -120,7 +121,7 @@ create(Context_t *ctx)
 void
 destroy(Context_t *ctx)
 {
-  if (vf != NULL) {
+  if (NULL != vf) {
     VectorField_delete(vf);
   }
 }
