@@ -22,7 +22,7 @@
 
 uint32_t version = 0;
 u_long options = BE_SFX2D|BEQ_NORANDOM;
-u_long mode = OVERLAY;
+enum LayerMode mode = LM_OVERLAY;
 char desc[] = "Test beat detection";
 char dname[] = "Test beat detection";
 
