@@ -20,10 +20,10 @@
 #include "context.h"
 
 
-u_long id = 944746507;
 uint32_t version = 0;
 u_long options = BE_WARP|BE_LENS;
 char desc[] = "Tunnel effect";
+char dname[] = "Tunnel";
 
 static u_long *tunnel;
 
