@@ -25,7 +25,7 @@ u_long options = BE_GFX|BEQ_MUTE_CAM|BEQ_NORANDOM;
 char desc[] = "DiffTV";
 char dname[] = "TV diff";
 
-u_long mode = OVERLAY;
+enum LayerMode mode = LM_OVERLAY;
 
 
 void
