@@ -37,7 +37,7 @@ u_long options = BE_GFX|BEQ_IMAGE|BEQ_MUTE_CAM;
 char desc[] = "NervousTV plugin from the EffecTV project";
 char dname[] = "TV nervous";
 
-u_long mode = OVERLAY;
+enum LayerMode mode = LM_OVERLAY;
 
 #define PLANES 8
 
