@@ -33,7 +33,7 @@ u_long options = BE_GFX|BEQ_WEBCAM|BEQ_MUTE_CAM;
 char desc[] = "QuarkTV plugin from the EffecTV project";
 char dname[] = "TV quark";
 
-u_long mode = OVERLAY;
+enum LayerMode mode = LM_OVERLAY;
 
 #define MIN_FRAMES 11
 
