@@ -33,7 +33,7 @@ u_long options = BE_GFX|BEQ_WEBCAM|BEQ_MUTE_CAM;
 char desc[] = "StreakTV plugin from the EffecTV project";
 char dname[] = "TV streak";
 
-u_long mode = OVERLAY;
+enum LayerMode mode = LM_OVERLAY;
 
 #define PLANES 32
 #define STRIDE 4
