@@ -24,7 +24,7 @@ u_long options = BE_GFX|BEQ_WEBCAM|BEQ_MUTE_CAM;
 char desc[] = "Webcam plugin";
 char dname[] = "TV webcam";
 
-u_long mode = OVERLAY;
+enum LayerMode mode = LM_OVERLAY;
 
 
 void
