@@ -19,11 +19,10 @@
 
 #include "context.h"
 
-u_long id = 945172539;
 uint32_t version = 0;
 u_long options = BE_WARP|BE_LENS;
 char desc[] = "Warp effect";
-
+char dname[] = "Warp";
 
 struct warp {
   void  *offstable;
