@@ -25,7 +25,6 @@
 
 #define NO_MOUSE_CURSOR
 
-u_long id = 1327695029;
 u_long options = BE_NONE;
 
 
@@ -286,9 +285,7 @@ create(Context_t *ctx)
   char *window_title;
   const int flags = SDL_WINDOW_OPENGL | SDL_GL_DOUBLEBUFFER;
 
-  /* Find default output plugin for OpenGL: GLCube */
-  /* FIXME hardcoded */
-  glcube = Plugins_find(1328382269);
+  glcube = Plugins_find("GLCube");
   if (NULL != glcube) {
     printf("[i] glcube found @%p\n", glcube);
     if (NULL != glcube->create) {
