@@ -26,7 +26,7 @@ char desc[] = "RTMP streamer";
 #define FFMPEG_CHECK     "ffmpeg -h >/dev/null 2>&1"
 #define FFMPEG           "ffmpeg"
 #define RTMP_FFMPEG_ARGS "-loglevel quiet -re -vcodec ppm -f image2pipe -i pipe: -f flv"
-#define RTMP_URL         "rtmp://localhost:1935/rtmp/"PACKAGE
+#define RTMP_URL         "rtmp://localhost/live"
 
 static FILE *rtmp = NULL;
 
@@ -87,7 +87,7 @@ run(Context_t *ctx)
   size_t res;
 
   /* get picture */
-  data = export_BGR_active_buffer(ctx, 1);
+  data = export_RGB_active_buffer(ctx, 1);
 
   memset(&buff, '\0', MAXLEN+1);
   g_snprintf(buff, MAXLEN, "P6  %d %d 255\n", WIDTH, HEIGHT);
