@@ -39,6 +39,8 @@ SDL_Window *osd_window = NULL;
 #define OSD_WIDTH  600
 #define OSD_HEIGHT 900
 
+extern uint8_t max_fps;
+
 
 static int
 osd_init()
@@ -121,21 +123,8 @@ osd_info(const Context_t *ctx)
                     (NULL != cur_seq->name) ? cur_seq->name : "(none)");
 
   /* Display current bankset:bank */
-  switch (ctx->bank_mode) {
-    case SEQUENCES:
-      dst_y = osd_print(BORDER, dst_y, 0, 0, "Sequences bank: %d-%d",
-                        ctx->bankset[SEQUENCES]+1, ctx->bank[SEQUENCES]+1);
-      break;
-    case COLORMAPS:
-      dst_y = osd_print(BORDER, dst_y, 0, 0, "Colormaps bank: %d-%d",
-                        ctx->bankset[COLORMAPS]+1, ctx->bank[COLORMAPS]+1);
-      break;
-    case IMAGES:
-      dst_y = osd_print(BORDER, dst_y, 0, 0, "Images bank: %d-%d",
-                        ctx->bankset[IMAGES]+1, ctx->bank[IMAGES]+1);
-      break;
-  }
-
+  dst_y = osd_print(BORDER, dst_y, 0, 0, "Sequences bank: %d-%d",
+                    ctx->bank_set + 1, ctx->bank + 1);
   /* Display colormap and image (if any) */
   if (NULL != colormaps) {
     dst_y = osd_print(BORDER, dst_y, 0, 0, "Colormap: %s",
@@ -193,7 +182,7 @@ osd_info(const Context_t *ctx)
 static void
 osd_fps(const Context_t *ctx)
 {
-  (void)osd_print(BORDER, 0, 1, 1, "%03d FPS (%03d)", (int)Context_fps(ctx), ctx->max_fps);
+  (void)osd_print(BORDER, 0, 1, 1, "%03d FPS (%03d)", (int)Context_fps(ctx), max_fps);
 }
 
 
@@ -290,33 +279,35 @@ osd_plugins(const Context_t *ctx)
     start += plugins->size;
   }
 
-  for (n = 0; (n < 2 * SHOW + 1) && (n < plugins->size); ) {
-    const char *arrow;
-    char in_sequence;
-    char *name;
-    Plugin_t *plugin = plugins->plugins[start];
+  if (NULL != plugins->plugins) {
+    for (n = 0; (n < 2 * SHOW + 1) && (n < plugins->size); ) {
+      const char *arrow;
+      char in_sequence;
+      char *name;
+      Plugin_t *plugin = plugins->plugins[start];
 
-    if (NULL != plugin) {
-      arrow = (n == SHOW) ? ARROW : "  ";
-      in_sequence = Sequence_find(ctx->sm->cur, plugin) ? '*' : ' ';
-      name = Plugin_dname(plugin);
-      (void)osd_print(BORDER, dst_y, 0, 1, "%c|%c|%c|%c|%c %s %c %s",
-                      ((*plugin->options & BE_SFX2D) || (*plugin->options & BE_SFX3D)) ? 'S' : ' ',
-                      (*plugin->options & BE_GFX)  ? 'G' : ' ',
-                      ((*plugin->options & BE_BLUR) || (*plugin->options & BE_DISPLACE)
-                       || (*plugin->options & BE_ROLL) || (*plugin->options & BE_WARP)
-                       || (*plugin->options & BE_SCROLL) || (*plugin->options & BE_MIRROR))  ? 'F' : ' ',
-                      ((*plugin->options & BEQ_IMAGE) || (*plugin->options & BEQ_SPLASH))  ? 'I' : ' ',
-                      (*plugin->options & BE_LENS)  ? 'L' : ' ',
-                      arrow, in_sequence, name);
-      xfree(name);
-      dst_y -= skip;
-    }
-    n++;
+      if (NULL != plugin) {
+        arrow = (n == SHOW) ? ARROW : "  ";
+        in_sequence = Sequence_find(ctx->sm->cur, plugin) ? '*' : ' ';
+        name = Plugin_dname(plugin);
+        (void)osd_print(BORDER, dst_y, 0, 1, "%c|%c|%c|%c|%c %s %c %s",
+                        ((*plugin->options & BE_SFX2D) || (*plugin->options & BE_SFX3D)) ? 'S' : ' ',
+                        (*plugin->options & BE_GFX)  ? 'G' : ' ',
+                        ((*plugin->options & BE_BLUR) || (*plugin->options & BE_DISPLACE)
+                         || (*plugin->options & BE_ROLL) || (*plugin->options & BE_WARP)
+                         || (*plugin->options & BE_SCROLL) || (*plugin->options & BE_MIRROR))  ? 'F' : ' ',
+                        ((*plugin->options & BEQ_IMAGE) || (*plugin->options & BEQ_SPLASH))  ? 'I' : ' ',
+                        (*plugin->options & BE_LENS)  ? 'L' : ' ',
+                        arrow, in_sequence, name);
+        xfree(name);
+        dst_y -= skip;
+      }
+      n++;
 
-    start++;
-    if (start == plugins->size) {
-      start = 0;
+      start++;
+      if (start == plugins->size) {
+        start = 0;
+      }
     }
   }
 }
@@ -382,10 +373,7 @@ osd(Context_t *ctx)
     osd_random_mode_elapsed(ctx);
   }
 
-  if (ctx->sync_fps) {
-    osd_fps(ctx);
-  }
-
+  osd_fps(ctx);
   osd_sequence(ctx);
 
   if (NULL != plugins) {
@@ -395,7 +383,7 @@ osd(Context_t *ctx)
   SequenceManager_unlock(ctx->sm);
 
   if (SDL_UpdateWindowSurface(osd_window) < 0) {
-    SDL_Log("SDL_UpdateWindowSurface failed: %s", SDL_GetError());
+    SDL_Log("[3] SDL_UpdateWindowSurface failed: %s", SDL_GetError());
     exit(1);
   }
 }
