@@ -20,15 +20,10 @@
 #ifndef __BINIOU_OSD_H
 #define __BINIOU_OSD_H
 
-void osd_init();
-void osd_quit();
-
-void osd(const Context_t *);
+void *osd_thread(void *attr);
 
 u_short osd_print(const u_short, u_short,
                   const u_char, const u_char,
                   const char *, ...);
 
-void osd(const Context_t *);
-
 #endif /* __BINIOU_OSD_H */
