@@ -22,7 +22,7 @@
 
 #include "biniou.h"
 
-void ttf_init();
+int ttf_init();
 void ttf_quit();
 
 #endif /* __BINIOU_TTF_H */
