@@ -36,7 +36,7 @@ Alarm_new(const u_short min, const u_short max)
 
   a = xcalloc(1, sizeof(Alarm_t));
 
-  a->timer = b_timer_new();
+  a->timer = b_timer_new("alarm");
   a->min = min;
   a->max = max;
   assert(a->min <= a->max);
