@@ -46,6 +46,7 @@ static int delays[MAX_TIMERS][2] = {
 };
 
 uint8_t start_with_first_sequence = 0;
+uint8_t use_hard_timers = 1;
 
 static pthread_t images_thread;
 static struct Images_thread_args {
@@ -188,6 +189,8 @@ biniou_new(const char *datadir, const char *pluginsdir,
     Sequences_new();
   }
 
+  b_timer_set_mode(use_hard_timers ? BT_HARD : BT_SOFT);
+
   VERBOSE(printf("[+] Biniou initialized\n"));
 }
 
@@ -401,8 +404,13 @@ biniou_go(const u_long nb_frames)
 void
 biniou_set_delay(const enum RandomDelays what, const int min, const int max)
 {
-  if ((max <= min) || (min < 1) || (max < 1)) {
-    xerror("Set random delay for %s: max (%d) must be > min (%d), both values must be > 1\n",
+  if ((min < 1) || (max < 1)) {
+    xerror("Set random delay for %s: min (%d) and max (%d) must be >= 1\n",
+           delay_names[what], min, max);
+  }
+
+  if (max < min) {
+    xerror("Set random delay for %s: max (%d) must be >= min (%d)\n",
            delay_names[what], max, min);
   }
 
