@@ -62,7 +62,7 @@ b_rand_int(void)
 uint32_t
 b_rand_int_range(int32_t begin, int32_t end)
 {
-  return g_rand_int_range(brand, begin, end);
+  return (begin == end) ? end : g_rand_int_range(brand, begin, end);
 }
 
 
