@@ -22,18 +22,23 @@
 
 #include "utils.h"
 
+enum BTimerMode { BT_SOFT = 0, BT_HARD };
 
 typedef struct BTimer_s {
-  struct timeval start;
-  struct timeval end;
+#ifdef DEBUG_TIMERS
+  const char *name;
+#endif
+  struct timeval h_start; // hard timers
+  uint64_t       s_start; // soft timers
 } BTimer_t;
 
 
-BTimer_t *b_timer_new(void);
+BTimer_t *b_timer_new(const char *); // name will be displayed when compiled with DEBUG_TIMERS
 void b_timer_delete(BTimer_t *);
+
 void b_timer_start(BTimer_t *);
-void b_timer_stop(BTimer_t *);
-void b_timer_restart(BTimer_t *);
-float b_timer_elapsed(BTimer_t *);
+float b_timer_elapsed(const BTimer_t *);
+
+void b_timer_set_mode(const enum BTimerMode);
 
 #endif /* __BINIOU_BTIMER_H */
