@@ -47,7 +47,7 @@ void
 Cmap8_delete(Cmap8_t *cmap)
 {
   xfree(cmap->name);
-  if (cmap->filename != NULL) {
+  if (NULL != cmap->filename) {
     xfree(cmap->filename);
   }
   xfree(cmap);
@@ -73,7 +73,7 @@ Cmap8_load(Cmap8_t *cmap, const char *filename)
   }
 
   stream = fopen(filename, "r");
-  if (stream == NULL) {
+  if (NULL == stream) {
     xperror("fopen");
   }
 
@@ -86,7 +86,7 @@ Cmap8_load(Cmap8_t *cmap, const char *filename)
 
     /* try to read an RGB */
     strret = fgets(prout, 1024, stream);
-    if (strret == NULL) {
+    if (NULL == strret) {
       fclose(stream);
       return -1;
     }
@@ -120,14 +120,14 @@ Cmap8_copy(const Cmap8_t *from, Cmap8_t *to)
 {
   u_short i;
 
-  assert(from != NULL);
-  assert(to != NULL);
+  assert(NULL != from);
+  assert(NULL != to);
 
-  if (to->name != NULL) {
+  if (NULL != to->name) {
     xfree(to->name);
   }
 
-  assert(from->name != NULL);
+  assert(NULL != from->name);
   to->name = strdup(from->name);
 
   to->id = from->id;
@@ -221,7 +221,7 @@ Cmap8_save(Cmap8_t *cmap)
   snprintf(filename, (MAXLEN-1)*sizeof(char), "%s.bin", cmap->filename);
 
   stream = fopen(filename, "w");
-  if (stream == NULL) {
+  if (NULL == stream) {
     printf("[!] failed to open '%s' for writing :(\n", filename);
     return -1;
   }
