@@ -22,7 +22,7 @@
 
 #include "cmap_8bits.h"
 #include "fader.h"
-#include "event.h"
+#include "commands.h"
 #include "shuffler.h"
 
 
@@ -48,7 +48,7 @@ void CmapFader_random(CmapFader_t *);
 void CmapFader_init(CmapFader_t *);
 void CmapFader_run(CmapFader_t *);
 
-int CmapFader_event(CmapFader_t *, const Event_t *);
+int CmapFader_command(CmapFader_t *, const enum Command);
 
 int CmapFader_ring(const CmapFader_t *);
 
