@@ -26,6 +26,8 @@ extern int hflip, vflip, webcams;
 extern char *video_base;
 #endif
 extern uint8_t statistics;
+extern uint8_t max_fps;
+extern uint8_t use_hard_timers;
 
 #define MIN_WIDTH  80
 #define MIN_HEIGHT 60
@@ -36,32 +38,37 @@ usage()
 {
   printf("Usage: " PACKAGE_NAME " [options]\n\n"
          "\t-b, --basedir <path>\tSet base directory [" DEFAULT_PLUGINSDIR "]\n"
+         "\t-c, --config <file>\tSet configuration file [~/" KEYFILE "]\n"
          "\t-d, --datadir <path>\tSet data directory [" DEFAULT_DATADIR "]\n"
-         "\t-z, --schemes <file>\tSet the schemes file [" DEFAULT_SCHEMES_FILE "]\n"
          "\t-f, --fullscreen\tSet fullscreen\n"
          "\t-h, --help\t\tDisplay this help\n"
          "\t-i, --input <plugin>\tSet input plugin [" DEFAULT_INPUT_PLUGIN "]\n"
-         "\t-m, --maxfps <fps>\tSet maximum framerate [%ld]\n"
+         "\t-m, --max-fps <fps>\tSet maximum framerate [%d]\n"
+         "\t-n, --no-borders\tDisable window borders\n"
          "\t-o, --output <plugin>\tSet output plugin [" DEFAULT_OUTPUT_PLUGIN "]\n"
-         "\t-r, --random <mode>\tSet auto-random mode\n"
-         "\t-v, --version\t\tDisplay the version and exit\n"
+         "\t-p, --pidfile <file>\tSet the PID file [%s]\n"
          "\t-q, --quiet\t\tSuppress messages\n"
-         "\t-c, --config <file>\tSet configuration file [~/" KEYFILE "]\n"
-         "\t-X, --xpos <x position>\tSet left position of the window\n"
-         "\t-Y, --ypos <y position>\tSet top position of the window\n"
+         "\t-r, --random <mode>\tSet auto-random mode\n"
+         "\t-s, --soft-timers\tUse soft timers instead of the system clock\n"
+         "\t-t, --themes <themes>\tComma-separated list of themes to use [biniou]\n"
+         "\t-v, --version\t\tDisplay the version and exit\n"
 #ifndef FIXED
          "\t-x, --width <width>\tSet width [%d]\n"
          "\t-y, --height <height>\tSet height [%d]\n"
 #endif
-         "\t-n, --noborder\tDisable window borders\n"
-         "\t-p, --pidfile <file>\tSet the PID file [%s]\n"
-         "\t-t, --themes <themes>\tComma-separated list of themes to use [biniou]\n"
+         "\t-z, --schemes <file>\tSet the schemes file [" DEFAULT_SCHEMES_FILE "]\n"
+
+#ifdef WITH_WEBCAM
+         "\t-C, --cam-flip <h|v>\tFlip webcam image horizontally/vertically\n"
+         "\t-D, --device <device>\tWebcam base [" DEFAULT_VIDEO_DEVICE "]\n"
+#endif
+         "\t-F, --fade <delay>\tSet fading delay (s)\n"
+         "\t-S, --stats\t\tDisplay statistics\n"
 #ifdef WITH_WEBCAM
          "\t-W, --webcams <webcams>\tNumber of webcams [%d]\n"
-         "\t-D, --device <device>\tWebcam base [" DEFAULT_VIDEO_DEVICE "]\n"
-         "\t-C, --camflip <h|v>\tFlip webcam image horizontally/vertically\n"
 #endif
-         "\t-S, --stats\t\tDisplay statistics\n"
+         "\t-X, --xpos <x position>\tSet left position of the window\n"
+         "\t-Y, --ypos <y position>\tSet top position of the window\n"
          "\n"
          "This version of " PACKAGE_STRING " was compiled with:\n"
          "\tInput plugins: " INPUT_PLUGINS "\n"
@@ -72,11 +79,11 @@ usage()
          "\n"
 #endif
          , max_fps
+         , pid_file
 #ifndef FIXED
          , DEFAULT_WIDTH
          , DEFAULT_HEIGHT
 #endif
-         , pid_file
 #ifdef WITH_WEBCAM
          , webcams
 #endif
@@ -95,43 +102,51 @@ getargs(int argc, char **argv)
   int w, h;
 #endif
 
+  static const char *arg_list = "b:c:C:d:D:fF:hi:m:no:p:qr:sSt:x:X:y:Y:vW:z:";
+
 #if HAVE_GETOPT_LONG
   static struct option long_opt[] = {
     {"basedir", required_argument, NULL, 'b'},
+    {"config", required_argument, NULL, 'c'},
     {"datadir", required_argument, NULL, 'd'},
-    {"schemes", required_argument, NULL, 'z'},
     {"fullscreen", no_argument, NULL, 'f'},
     {"help", no_argument, NULL, 'h'},
     {"input", required_argument, NULL, 'i'},
-    {"maxfps", required_argument, NULL, 'm'},
-    {"noborder", no_argument, NULL, 'n'},
+    {"max-fps", required_argument, NULL, 'm'},
+    {"no-borders", no_argument, NULL, 'n'},
     {"output", required_argument, NULL, 'o'},
-    {"random", required_argument, NULL, 'r'},
+    {"pidfile", required_argument, NULL, 'p'},
     {"quiet", no_argument, NULL, 'q'},
-    {"config", required_argument, NULL, 'c'},
-    {"xpos", required_argument, NULL, 'X'},
-    {"ypos", required_argument, NULL, 'Y'},
+    {"random", required_argument, NULL, 'r'},
+    {"soft-timers", no_argument, NULL, 's'},
+    {"themes", required_argument, NULL, 't'},
+    {"version", no_argument, NULL, 'v'},
 #ifndef FIXED
     {"width", required_argument, NULL, 'x'},
     {"height", required_argument, NULL, 'y'},
 #endif
-    {"version", no_argument, NULL, 'v'},
-    {"pidfile", required_argument, NULL, 'p'},
-    {"themes", required_argument, NULL, 't'},
+    {"schemes", required_argument, NULL, 'z'},
+
 #ifdef WITH_WEBCAM
-    {"camflip", required_argument, NULL, 'C'},
-    {"webcams", required_argument, NULL, 'W'},
+    {"cam-flip", required_argument, NULL, 'C'},
     {"device", required_argument, NULL, 'D'},
 #endif
+    {"fade", required_argument, NULL, 'F'},
     {"stats", no_argument, NULL, 'S'},
+#ifdef WITH_WEBCAM
+    {"webcams", required_argument, NULL, 'W'},
+#endif
+    {"xpos", required_argument, NULL, 'X'},
+    {"ypos", required_argument, NULL, 'Y'},
+
     {0, 0, 0, 0}
   };
 
 
   /* Get command line arguments */
-  while ((ch = getopt_long(argc, argv, "b:c:C:d:D:fhi:m:no:p:qr:St:x:X:y:Y:vW:z:", long_opt, NULL)) != -1)
+  while ((ch = getopt_long(argc, argv, arg_list, long_opt, NULL)) != -1)
 #else
-  while ((ch = getopt(argc, argv, "b:c:C:d:D:fhi:m:no:p:qr:St:x:X:y:Y:vW:z:")) != -1)
+  while ((ch = getopt(argc, argv, arg_list)) != -1)
 #endif
     switch (ch) {
       case 'b':
@@ -201,9 +216,9 @@ getargs(int argc, char **argv)
       case 'm':
         max_fps = xatol(optarg);
         if (max_fps > 0) {
-          VERBOSE(printf("[c] Maximum fps set to %li\n", max_fps));
+          VERBOSE(printf("[c] Maximum fps set to %i\n", max_fps));
         } else {
-          xerror("Invalid max_fps (%li)\n", max_fps);
+          xerror("Invalid max_fps (%d)\n", max_fps);
         }
         break;
 
@@ -296,11 +311,21 @@ getargs(int argc, char **argv)
         break;
 #endif
 
+      case 's':
+        use_hard_timers = 0;
+        VERBOSE(printf("[k] Using %s timers\n", use_hard_timers ? "hard" : "soft"));
+        break;
+
       case 'S':
         libbiniou_verbose = 0;
         statistics = 1;
         break;
 
+      case 'F':
+        fade_delay = xatof(optarg);
+        VERBOSE(printf("[c] Fading delay set to %f\n", fade_delay));
+        break;
+
       default:
         usage();
         break;
