@@ -63,9 +63,6 @@ extern unsigned short WIDTH, HEIGHT;
 /* default configuration file */
 #define KEYFILE "." PACKAGE_NAME "rc"
 
-/* banks */
-#define MAX_BANKS 12
-
 /* 3D z-buffer */
 #define ZMAX 6.0
 
@@ -84,4 +81,7 @@ extern unsigned short WIDTH, HEIGHT;
 /* delay for ancillary threads (OSD, webcams) */
 #define THREADS_DELAY 40
 
+/* default fps */
+#define DEFAULT_MAX_FPS 50
+
 #endif /* __BINIOU_CONSTANTS_H */
