@@ -17,6 +17,7 @@
  *  along with lebiniou. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <inttypes.h>
 #include "globals.h"
 #include "context.h"
 #include "brandom.h"
@@ -31,6 +32,9 @@ double rot_amount = DEFAULT_ROT_AMOUNT;
 double scale_factor = -1.0;
 /* maximum rotation factor */
 uint8_t rotation_factor = DEFAULT_ROT_FACTOR;
+/* global variables needed for soft timers use */
+uint64_t frames = 0;
+uint8_t  max_fps = DEFAULT_MAX_FPS;
 
 
 static enum ShufflerMode random_modes[MAX_TIMERS] = {
@@ -48,12 +52,12 @@ static enum ShufflerMode random_modes[MAX_TIMERS] = {
 
 extern char *video_base;
 
-
 static webcam_t *cams[MAX_CAMS];
 static pthread_t thr[MAX_CAMS];
 
 #define MAX_TRIES 5
 
+
 static void
 Context_open_webcam(Context_t *ctx)
 {
@@ -138,6 +142,7 @@ Context_new(const int webcams)
   ctx->sm = SequenceManager_new();
 
   Context_load_banks(ctx);
+  Context_load_shortcuts(ctx);
 
   VERBOSE(printf("[+] Initializing 3D engine\n"));
   /* Compute scale factor if undefined */
@@ -146,14 +151,12 @@ Context_new(const int webcams)
   }
   Params3d_init(&ctx->params3d, rot_amount, scale_factor, rotation_factor);
 
-  ctx->events = NULL;
-  ctx->frames = ctx->nb_events = 0;
   for (i = 0; i < NFPS; i++) {
     ctx->fps[i] = 0;
   }
 
-  ctx->timer = b_timer_new();
-  ctx->fps_timer = b_timer_new();
+  ctx->timer = b_timer_new("timer");
+  ctx->fps_timer = b_timer_new("fps_timer");
 
   ctx->display_colormap = 0;
 
@@ -239,7 +242,7 @@ Context_delete(Context_t *ctx)
   }
 #endif
 
-  VERBOSE(printf("[i] %lu frames, %lu events\n", ctx->frames, ctx->nb_events));
+  VERBOSE(printf("[i] %"PRIu64" frames\n", frames));
 
   if (NULL != ctx->input_plugin) {
     Plugin_delete(ctx->input_plugin);
@@ -439,8 +442,8 @@ Context_update_auto(Context_t *ctx)
 
 
 int
-Context_add_rand(Sequence_t *seq,
-                 const enum PluginOptions options, const int not_lens, const Plugin_t *locked)
+Context_add_rand(Sequence_t *seq, const enum PluginOptions options,
+                 const int not_lens, const Plugin_t *locked, const uint8_t random_layers)
 {
   Plugin_t *p;
 
@@ -451,7 +454,7 @@ Context_add_rand(Sequence_t *seq,
     }
   } while (NULL != Sequence_find(seq, p));
 
-  Sequence_insert(seq, p);
+  Sequence_insert(seq, p, random_layers);
 
   if ((*p->options & BE_LENS) && !not_lens && (NULL == seq->lens)) {
     seq->lens = p;
@@ -506,7 +509,7 @@ Context_insert_plugin(Context_t *ctx, Plugin_t *p)
     p->on_switch_on(ctx);
   }
 
-  Sequence_insert(ctx->sm->cur, p);
+  Sequence_insert(ctx->sm->cur, p, 0);
 }
 
 
@@ -524,12 +527,11 @@ Context_remove_plugin(Context_t *ctx, Plugin_t *p)
 
 
 void
-Context_set_max_fps(Context_t *ctx, const u_short max_fps)
+Context_set_max_fps(Context_t *ctx, const uint8_t _max_fps)
 {
-  ctx->sync_fps = 1;
-  assert(max_fps);
-  ctx->max_fps = max_fps;
-  ctx->i_max_fps = 1.0 / ctx->max_fps;
+  assert(_max_fps);
+  max_fps = _max_fps;
+  ctx->i_max_fps = 1.0 / max_fps;
 }
 
 
@@ -559,10 +561,10 @@ Context_previous_sequence(Context_t *ctx)
   if (NULL != ctx->sm->curseq) {
     Sequence_t *s;
 
-    if (NULL != ctx->sm->curseq->next) {
-      ctx->sm->curseq = ctx->sm->curseq->next;
+    if (NULL != ctx->sm->curseq->prev) {
+      ctx->sm->curseq = ctx->sm->curseq->prev;
     } else {
-      ctx->sm->curseq = g_list_first(sequences->seqs);
+      ctx->sm->curseq = g_list_last(sequences->seqs);
     }
 
     s = (Sequence_t *)ctx->sm->curseq->data;
@@ -579,10 +581,10 @@ Context_next_sequence(Context_t *ctx)
   if (NULL != ctx->sm->curseq) {
     Sequence_t *s;
 
-    if (NULL != ctx->sm->curseq->prev) {
-      ctx->sm->curseq = ctx->sm->curseq->prev;
+    if (NULL != ctx->sm->curseq->next) {
+      ctx->sm->curseq = ctx->sm->curseq->next;
     } else {
-      ctx->sm->curseq = g_list_last(sequences->seqs);
+      ctx->sm->curseq = g_list_first(sequences->seqs);
     }
 
     s = (Sequence_t *)ctx->sm->curseq->data;
@@ -632,59 +634,20 @@ Context_random_sequence(Context_t *ctx)
 void
 Context_set_sequence(Context_t *ctx, const uint32_t id)
 {
-  Sequence_t *seq = Sequences_find(id);
+  GList *seq = Sequences_find(id);
 
-  if (NULL == seq)
-    if (ctx->sm->transient->id == id) {
-      seq = ctx->sm->transient;
-    }
-
-  assert(NULL != seq);
-  ctx->sm->curseq = seq->layers;
-  Sequence_copy(ctx, seq, ctx->sm->next);
-
-  Context_set(ctx);
-}
-
-
-void
-Context_use_sequence_bank(Context_t *ctx, const u_char bank)
-{
-  u_long id;
-
-  id = ctx->banks[SEQUENCES][ctx->bankset[SEQUENCES]][bank];
-  if (id) {
-    Sequence_t *seq;
-
-    printf("[i] Using sequence in bank #%d\n", (bank+1));
-
-    VERBOSE(printf("[s] Set sequence: %li\n", id));
-
-    seq = Sequences_find(id);
-    if (NULL == seq)
-      if (ctx->sm->transient->id == id) {
-        seq = ctx->sm->transient;
-      }
-    assert(NULL != seq);
-    ctx->sm->curseq = seq->layers;
-    Sequence_copy(ctx, seq, ctx->sm->next);
-
-    ctx->bank[SEQUENCES] = bank;
+  if (NULL != seq) {
+    Sequence_t *s = (Sequence_t *)seq->data;
+    ctx->sm->curseq = seq;
+    Sequence_copy(ctx, s, ctx->sm->next);
 
     Context_set(ctx);
   } else {
-    printf("[i] Bank %d/%d is empty\n", ctx->bankset[SEQUENCES]+1, bank+1);
+    printf("[!] Sequence %d not found\n", id);
   }
 }
 
 
-void
-Context_clear_bank(Context_t *ctx, const u_char bank)
-{
-  ctx->banks[ctx->bank_mode][ctx->bankset[ctx->bank_mode]][bank] = 0;
-}
-
-
 Buffer8_t *
 active_buffer(const Context_t *ctx)
 {
@@ -776,6 +739,20 @@ Context_mix_buffers(const Context_t *ctx, Buffer8_t *buffs[2])
 }
 
 
+void
+Context_interleave_buffers(const Context_t *ctx)
+{
+  const Pixel_t *src = passive_buffer(ctx)->buffer;
+  Pixel_t *dst = active_buffer(ctx)->buffer;
+
+  for (uint16_t l = 0; l < HEIGHT; l += 2) {
+    memcpy(dst, src, WIDTH * sizeof(Pixel_t));
+    src += 2 * WIDTH * sizeof(Pixel_t);
+    dst += 2 * WIDTH * sizeof(Pixel_t);
+  }
+}
+
+
 /* ulfius */
 #ifdef WITH_ULFIUS
 void
