@@ -36,10 +36,15 @@
 #include "bulfius.h"
 #endif
 
-#define NFPS     25 /* to get mean fps */
+#define NFPS          25 /* to get mean fps */
+#define MAX_BANKS     12
+#define MAX_SHORTCUTS 10
+
 
 enum RandomMode { BR_NONE = 0, BR_SEQUENCES, BR_SCHEMES, BR_BOTH, BR_NB };
 
+enum Shorcuts { SH_COLORMAP = 0, SH_IMAGE, SH_NB };
+
 /* Random changes delays */
 #define DELAY_MIN 15
 #define DELAY_MAX 30
@@ -65,6 +70,7 @@ enum RandomDelays { BD_COLORMAPS = 0, BD_IMAGES, BD_SEQUENCES
 /* store the last N frames from the webcam -same as EffectTV */
 #define CAM_SAVE 32
 
+
 typedef struct BKey_s {
   uint32_t val;
   uint16_t mod;
@@ -118,31 +124,26 @@ typedef struct Context_s {
   enum RandomMode random_mode;
   Alarm_t  *a_random;
 
-  u_long   frames;
-
-  GList    *events;
-  u_long   nb_events;
-
   BTimer_t *timer;
 
   /* FPS stuff */
-  u_char   sync_fps:1;
-  u_short  max_fps;
   float    i_max_fps; /* inverse of the maximum frames per second */
   int      fps[NFPS];
   BTimer_t  *fps_timer;
 
   uint8_t  window_decorations:1;
-  u_char   fullscreen:1;
-  u_char   display_colormap:1;
-  u_char   take_screenshot:1;
-  u_char   bypass:1;
+  uint8_t  fullscreen:1;
+  uint8_t  display_colormap:1;
+  uint8_t  take_screenshot:1;
+  uint8_t  bypass:1;
 
   /* Banks */
-  u_char   bank_mode; /* will default to SEQUENCES */
-  uint32_t banks[3][MAX_BANKS][MAX_BANKS];
-  u_char   bankset[3];
-  u_char   bank[3]; /* the bank used */
+  uint32_t banks[MAX_BANKS][MAX_BANKS];
+  uint8_t  bank_set; // current bankset
+  uint8_t  bank; // current bank
+
+  /* Shortcuts */
+  uint32_t shortcuts[SH_NB][MAX_SHORTCUTS];
 
   /* OpenGL */
 #ifdef WITH_GL
@@ -165,7 +166,7 @@ typedef struct Context_s {
   char auto_colormaps;
   char auto_images;
 
-  /* used to randomly mix buffers */
+  /* used to randomly mix buffers, values: 0 | 1 */
   Buffer8_t *random;
 
   /* ulfius */
@@ -185,10 +186,10 @@ void Context_run(Context_t *);
 void Context_update(Context_t *);
 void Context_update_auto(Context_t *);
 
-int  Context_add_rand(Sequence_t *, const enum PluginOptions, const int, const Plugin_t *);
+int  Context_add_rand(Sequence_t *, const enum PluginOptions, const int, const Plugin_t *, const uint8_t);
 void Context_randomize(Context_t *);
 
-void Context_set_max_fps(Context_t *, const u_short);
+void Context_set_max_fps(Context_t *, const uint8_t);
 void Context_set_engine_random_mode(Context_t *, const enum RandomMode);
 
 void Context_insert_plugin(Context_t *, Plugin_t *);
@@ -203,12 +204,7 @@ void Context_latest_sequence(Context_t *);
 void Context_random_sequence(Context_t *);
 void Context_set_sequence(Context_t *, const uint32_t);
 
-/* Events */
-int Context_event(Context_t *, const Event_t *); /* TODO void ? */
-void Context_process_events(Context_t *);
-void Context_add_event(Context_t *, const Event_t *);
-void Context_send_event(Context_t *, const enum RcptTo, const enum Command,
-                        const enum Arg);
+void Context_process_command(Context_t *, const enum Command);
 
 Buffer8_t *active_buffer(const Context_t *);
 Buffer8_t *passive_buffer(const Context_t *);
@@ -243,10 +239,7 @@ pop_buffer(const Context_t *ctx)
 
 /* TODO: deprecate export_RGB*, use export RGBA* */
 Pixel_t *export_RGB_buffer(const Context_t *, const u_char, const u_char);
-Pixel_t *export_BGR_buffer(const Context_t *, const u_char, const u_char);
-
 Pixel_t *export_RGB_active_buffer(const Context_t *, const u_char);
-Pixel_t *export_BGR_active_buffer(const Context_t *, const u_char);
 
 Pixel_t *export_YUV_buffer(const Context_t *, const u_char, const u_char);
 Pixel_t *export_YUV_active_buffer(const Context_t *, const u_char);
@@ -254,12 +247,16 @@ Pixel_t *export_YUV_active_buffer(const Context_t *, const u_char);
 const RGBA_t *export_RGBA_buffer(const Context_t *, const u_char);
 const RGBA_t *export_RGBA_active_buffer(const Context_t *);
 
+/* Banks */
 void Context_save_banks(const Context_t *);
 void Context_load_banks(Context_t *);
-void Context_use_sequence_bank(Context_t *, const u_char);
-void Context_clear_bank(Context_t *, const u_char);
-void Context_store_bank(Context_t *, const u_char);
-void Context_use_bankset(Context_t *, const u_char);
+void Context_use_sequence_bank(Context_t *, const uint8_t);
+void Context_clear_bank(Context_t *, const uint8_t);
+void Context_store_bank(Context_t *, const uint8_t);
+
+/* Shortcuts */
+void Context_save_shortcuts(const Context_t *);
+void Context_load_shortcuts(Context_t *);
 
 void Context_push_webcam(Context_t *, Buffer8_t *, const int);
 
@@ -279,10 +276,14 @@ void Context_set_volume_scale(Context_t *, const double);
 double Context_get_volume_scale(const Context_t *);
 
 void Context_mix_buffers(const Context_t *, Buffer8_t *[2]);
+void Context_interleave_buffers(const Context_t *);
 
 #ifdef WITH_ULFIUS
 void Context_start_ulfius(Context_t *);
 void Context_stop_ulfius(Context_t *);
 #endif
 
+/* commands */
+void on_key(Context_t *, const BKey_t *);
+
 #endif /* __BINIOU_CONTEXT_H */
