@@ -50,36 +50,6 @@ export_RGB_buffer(const Context_t *ctx, const u_char screen, const u_char flip)
 }
 
 
-Pixel_t *
-export_BGR_buffer(const Context_t *ctx, const u_char screen, const u_char flip)
-{
-  rgba_t *colors = &ctx->cf->cur->colors[0];
-  Buffer8_t *buf = ctx->buffers[screen];
-  const Pixel_t *src = NULL;
-  Pixel_t *res;
-  u_long c, i = 0;
-
-  if (flip) {
-    Buffer8_flip_v(buf);
-  }
-  src = buf->buffer;
-
-  res = xmalloc(3*BUFFSIZE*sizeof(Pixel_t));
-
-  for (c = 0; c < BUFFSIZE; c++) {
-    res[i++] = colors[src[c]].col.b;
-    res[i++] = colors[src[c]].col.g;
-    res[i++] = colors[src[c]].col.r;
-  }
-
-  if (flip) {
-    Buffer8_flip_v(buf);
-  }
-
-  return res;
-}
-
-
 Pixel_t *
 export_RGB_active_buffer(const Context_t *ctx, const u_char flip)
 {
@@ -87,13 +57,6 @@ export_RGB_active_buffer(const Context_t *ctx, const u_char flip)
 }
 
 
-Pixel_t *
-export_BGR_active_buffer(const Context_t *ctx, const u_char flip)
-{
-  return export_BGR_buffer(ctx, ACTIVE_BUFFER, flip);
-}
-
-
 Pixel_t *
 export_YUV_buffer(const Context_t *ctx, const u_char screen, const u_char flip)
 {
