@@ -19,6 +19,8 @@
 
 #include "fader.h"
 
+float fade_delay = DEFAULT_FADE_DELAY; // Fade delay in seconds
+
 
 Fader_t *
 Fader_new(const u_long size)
@@ -33,7 +35,7 @@ Fader_new(const u_long size)
   fa->fading = 1;
   fa->max = 0;
   fa->faded = 0;
-  fa->timer = b_timer_new();
+  fa->timer = b_timer_new("fader");
 
   return fa;
 }
