@@ -24,7 +24,9 @@
 #include "btimer.h"
 
 /* default fade delay in seconds */
-#define FADE_DELAY 3
+#define DEFAULT_FADE_DELAY 3
+
+extern float fade_delay;
 
 /* for fading timers */
 #define MFACTOR    1000
@@ -49,7 +51,7 @@ static inline void
 Fader_init(Fader_t *fa)
 {
   /* we fade by msecs */
-  fa->max = (u_long)(FADE_DELAY * MFACTOR);
+  fa->max = (u_long)(fade_delay * MFACTOR);
   fa->faded = 0;
 }
 
