@@ -26,8 +26,8 @@ void
 image_filter_average(Buffer8_t *dst, const Buffer8_t *src, enum FilterType type,
                      enum BorderMode borders, u_short size, u_short *filter)
 {
-  assert(dst != NULL);
-  assert(src != NULL);
+  assert(NULL != dst);
+  assert(NULL != src);
 
   u_short hsize = (size - 1) / 2;
   u_short sum_f = 0;
@@ -158,8 +158,30 @@ image_filter_average(Buffer8_t *dst, const Buffer8_t *src, enum FilterType type,
         }
       break;
 
+
+    case FT_BLUR_GAUSSIAN_3x3:
+      filter = filter_BLUR_GAUSSIAN_3x3;
+      size   = FILTER_BLUR_GAUSSIAN_3x3_SIZE;
+      sum_f  = FILTER_BLUR_GAUSSIAN_3x3_SUM;
+
+      for (u_short j = 1; j < MAXY; j++)
+        for (u_short i = 1; i < MAXX; i++) {
+          u_long sum = get_pixel_nc(src, i - 1, j) * 2;
+          sum += get_pixel_nc(src, i, j - 1)* 2 ;
+          sum += get_pixel_nc(src, i, j) * 4;
+          sum += get_pixel_nc(src, i, j + 1) * 2;
+          sum += get_pixel_nc(src, i + 1, j) * 2;
+          sum += get_pixel_nc(src, i + 1, j + 1);
+          sum += get_pixel_nc(src, i + 1, j - 1);
+          sum += get_pixel_nc(src, i - 1, j + 1);
+          sum += get_pixel_nc(src, i - 1, j - 1);
+
+          set_pixel_nc(dst, i, j, (Pixel_t)(sum / FILTER_BLUR_GAUSSIAN_3x3_SUM));
+        }
+      break;
+
     case FT_GENERIC:
-      assert(filter != NULL);
+      assert(NULL != filter);
       assert(size % 2 == 1);
 
       for (u_short a = 0; a < size; a++)
