@@ -30,7 +30,8 @@ enum FilterType { FT_GENERIC = 0,
                   FT_VBLUR_3x3,
                   FT_HBLUR_3x3,
                   FT_DBLUR1_3x3,
-                  FT_DBLUR2_3x3
+                  FT_DBLUR2_3x3,
+                  FT_BLUR_GAUSSIAN_3x3
                 } FilterType_e;
 
 enum BorderMode { BM_NONE = 0, BM_CLEAR, BM_LOCAL, BM_TOROIDAL, BM_NB } BorderMode_e;
@@ -93,6 +94,14 @@ u_short filter_DBLUR2_3x3[3*3] = {
   2, 0, 1
 };
 
+#define FILTER_BLUR_GAUSSIAN_3x3_SIZE 3
+#define FILTER_BLUR_GAUSSIAN_3x3_SUM 16
+u_short filter_BLUR_GAUSSIAN_3x3[3*3] = {
+  1, 2, 1,
+  2, 4, 2,
+  1, 2, 1
+};
+
 /* filter size must be size*size */
 void image_filter_average(Buffer8_t *dst, const Buffer8_t *src,
                           enum FilterType type, enum BorderMode borders, u_short size, u_short *filter);
