@@ -22,7 +22,7 @@
 
 #include "image_8bits.h"
 #include "fader.h"
-#include "event.h"
+#include "commands.h"
 #include "shuffler.h"
 
 
@@ -47,7 +47,7 @@ void ImageFader_random(ImageFader_t *);
 void ImageFader_init(ImageFader_t *);
 void ImageFader_run(ImageFader_t *);
 
-int ImageFader_event(ImageFader_t *, const Event_t *);
+int ImageFader_command(ImageFader_t *, const enum Command);
 
 int ImageFader_ring(const ImageFader_t *);
 
