@@ -31,10 +31,10 @@ Images_compare(const void *_a, const void *_b)
   Image8_t **a = (Image8_t **)_a;
   Image8_t **b = (Image8_t **)_b;
 
-  assert(*a != NULL);
-  assert(*b != NULL);
-  assert((*a)->dname != NULL);
-  assert((*b)->dname != NULL);
+  assert(NULL != *a);
+  assert(NULL != *b);
+  assert(NULL != (*a)->dname);
+  assert(NULL != (*b)->dname);
 
   return strcasecmp((*a)->dname, (*b)->dname);
 }
@@ -50,13 +50,13 @@ Images_new(const char *basedir, const char *themes)
   GSList *t;
   gchar **tokens, **theme;
 
-  assert(basedir != NULL);
-  assert(themes != NULL);
+  assert(NULL != basedir);
+  assert(NULL != themes);
 
   tokens = g_strsplit(themes, ",", 0);
   theme = tokens;
 
-  for ( ; *theme != NULL; theme++) {
+  for ( ; NULL != *theme; theme++) {
     char *directoryname;
     char *th = *theme;
 
@@ -75,14 +75,14 @@ Images_new(const char *basedir, const char *themes)
     }
 
     dir = opendir(directoryname);
-    if (dir == NULL) {
+    if (NULL == dir) {
       fprintf(stderr, "[!] Error while reading image directory %s content: %s\n",
               directoryname, strerror(errno));
       g_free(directoryname);
       continue;
     }
 
-    while ((entry = readdir(dir)) != NULL) {
+    while (NULL != (entry = readdir(dir))) {
       uint32_t hash;
       Image8_t *pic;
 
@@ -93,9 +93,7 @@ Images_new(const char *basedir, const char *themes)
       hash = FNV_hash(entry->d_name);
 
       char ignore = 0;
-      for (t = g_slist_next(tmp);
-           t != NULL;
-           t = g_slist_next(t))
+      for (t = g_slist_next(tmp); NULL != t; t = g_slist_next(t))
         if (((Image8_t *)t->data)->id == hash) {
           const char *name = ((Image8_t *)t->data)->name;
 
@@ -136,9 +134,7 @@ Images_new(const char *basedir, const char *themes)
     uint16_t i;
 
     images->imgs = xmalloc(size * sizeof(Image8_t *));
-    for (i = 0, t = tmp;
-         t != NULL;
-         t = g_slist_next(t), i++) {
+    for (i = 0, t = tmp; NULL != t; t = g_slist_next(t), i++) {
       images->imgs[i] = (Image8_t *)t->data;
     }
     g_slist_free(tmp);
@@ -155,7 +151,7 @@ Images_new(const char *basedir, const char *themes)
 void
 Images_delete()
 {
-  if (images != NULL) {
+  if (NULL != images) {
     uint16_t i;
 
     for (i = 0; i < images->size; i++) {
@@ -172,7 +168,7 @@ Images_name(const uint32_t id)
 {
   uint16_t i;
 
-  if (images == NULL) {
+  if (NULL == images) {
     VERBOSE(fprintf(stderr, "[!] No images loaded\r\n"));
     return NULL;
   }
@@ -197,7 +193,7 @@ Images_index(const uint32_t id)
 {
   uint16_t i;
 
-  if (images == NULL) {
+  if (NULL == images) {
     fprintf(stderr, "[!] No images loaded\r\n");
     return -1;
   }
@@ -218,7 +214,7 @@ Images_find(const char *name)
 {
   uint16_t i;
 
-  if (images == NULL) {
+  if (NULL == images) {
     fprintf(stderr, "[!] No images loaded\r\n");
     return 0;
   }
@@ -239,7 +235,7 @@ Images_random_id()
 {
   uint16_t idx = 0;
 
-  assert(images != NULL);
+  assert(NULL != images);
   assert(images->size); // There is at least a default image
 
   if (images->size > 1) {
@@ -255,7 +251,7 @@ Images_random()
 {
   uint16_t idx = 0;
 
-  assert(images != NULL);
+  assert(NULL != images);
 
   if (images->size > 1) {
     idx = b_rand_int_range(0, images->size - 1);
