@@ -109,7 +109,7 @@ Input_new(const uint32_t size)
   }
 
 #ifdef DEBUG
-  input->timer = b_timer_new();
+  input->timer = b_timer_new("input");
 #endif
 
   input->volume_scale = 1.0;
@@ -196,7 +196,7 @@ Input_do_fft(Input_t *input)
 
     input->max_spectrum_log[c] = input->spectrum_log[c][new_max];
 
-#ifdef XDEBUG
+#ifdef DEBUG_INPUT_SPECTRUM
     if (c == A_MONO) {
       printf("[s] %d % 3d\tspectrum: %f\tspectrum_log: %f\n",
              c, new_max,
@@ -206,7 +206,7 @@ Input_do_fft(Input_t *input)
 #endif
   }
 
-#ifdef XDEBUG
+#ifdef DEBUG_INPUT_FFTW
   printf("[i] FFT time: %f ms\n", b_timer_elapsed(input->timer) * 1000);
 #endif
 }
