@@ -45,6 +45,7 @@ extern double scale_factor; // 3D scale factor
 extern double rot_amount;
 extern uint8_t rotation_factor;
 extern uint8_t start_with_first_sequence;
+extern uint8_t use_hard_timers;
 
 
 static void process_timers(GKeyFile *);
@@ -65,6 +66,7 @@ process(GKeyFile *kf)
   gint kf_width, kf_height;
 #endif
   gint kf_fps, kf_rnd;
+  gdouble kf_fade_delay;
 #ifdef WITH_WEBCAM
   gchar whflip = FALSE, wvflip = FALSE;
   gint kf_webcams;
@@ -74,6 +76,7 @@ process(GKeyFile *kf)
   gchar *kf_data_dir = NULL;
   double kf_volume_scale = 0;
   gchar first_sequence = FALSE;
+  gchar hard_timers = FALSE;
 
   input = g_key_file_get_string(kf, PLUGINS, "Input", NULL);
   if (NULL != input) {
@@ -154,13 +157,24 @@ process(GKeyFile *kf)
     if (kf_fps > 0)
       if (max_fps != kf_fps) {
         max_fps = kf_fps;
-        VERBOSE(printf("[k] Setting FPS to %li\n", max_fps));
+        VERBOSE(printf("[k] Setting FPS to %d\n", max_fps));
       }
   } else {
     g_error_free(error);
     error = NULL;
   }
 
+  kf_fade_delay = g_key_file_get_double(kf, ENGINE, "FadeDelay", &error);
+  if (NULL == error) {
+    if (kf_fade_delay >= 0 && fade_delay != kf_fade_delay) {
+      fade_delay = kf_fade_delay;
+      VERBOSE(printf("[k] Setting fade delay to %.2f s\n", fade_delay));
+    }
+  } else {
+    g_error_free(error);
+    error = NULL;
+  }
+
   kf_rnd = g_key_file_get_integer(kf, ENGINE, "RandomMode", &error);
   if (NULL == error) {
     if ((kf_rnd >= BR_NONE) && (kf_rnd <= BR_BOTH))
@@ -265,6 +279,15 @@ process(GKeyFile *kf)
     VERBOSE(printf("[k] Plugins: blacklist of %"G_GSIZE_FORMAT" plugins\n", blacklist_length));
   }
   Plugins_set_blacklist(blacklist);
+
+  hard_timers = g_key_file_get_boolean(kf, ENGINE, "HardTimers", &error);
+  if (NULL == error) {
+    use_hard_timers = hard_timers;
+    VERBOSE(printf("[k] Using %s timers\n", use_hard_timers ? "hard" : "soft"));
+  } else {
+    g_error_free(error);
+    error = NULL;
+  }
 }
 
 
