@@ -17,8 +17,8 @@
  *  along with lebiniou. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __BINIOU_EVENTS_H
-#define __BINIOU_EVENTS_H
+#ifndef __BINIOU_KEYS_H
+#define __BINIOU_KEYS_H
 
 #include <SDL2/SDL.h>
 #include "biniou.h"
@@ -40,7 +40,7 @@ BKEY(const BKey_t *k, const uint32_t v)
 static inline int
 BSHIFT(const BKey_t *k, const uint32_t v)
 {
-  return ((k->val == v) && (k->mod & KMOD_SHIFT) && !(k->mod & KMOD_CTRL) && !(k->mod & KMOD_ALT));
+  return ((k->val == v) && !(k->mod & KMOD_CTRL) && (k->mod & KMOD_SHIFT) && !(k->mod & KMOD_ALT));
 }
 
 
@@ -51,10 +51,17 @@ BCTRL(const BKey_t *k, const uint32_t v)
 }
 
 
+static inline int
+BCTRLALT(const BKey_t *k, const uint32_t v)
+{
+  return ((k->val == v) && (k->mod & KMOD_CTRL) && !(k->mod & KMOD_SHIFT) && (k->mod & KMOD_ALT));
+}
+
+
 static inline int
 BALT(const BKey_t *k, const uint32_t v)
 {
-  return ((k->val == v) && (k->mod & KMOD_ALT) && !(k->mod & KMOD_SHIFT) && !(k->mod & KMOD_CTRL));
+  return ((k->val == v) && !(k->mod & KMOD_CTRL) && !(k->mod & KMOD_SHIFT) && (k->mod & KMOD_ALT));
 }
 
 
@@ -68,7 +75,14 @@ BCTRLSHIFT(const BKey_t *k, const uint32_t v)
 static inline int
 BALTSHIFT(const BKey_t *k, const uint32_t v)
 {
-  return ((k->val == v) && (k->mod & KMOD_ALT) && (k->mod & KMOD_SHIFT));
+  return ((k->val == v) && !(k->mod & KMOD_CTRL) && (k->mod & KMOD_SHIFT) && (k->mod & KMOD_ALT));
 }
 
-#endif /* __BINIOU_EVENTS_H */
+static inline int
+BCTRLALTSHIFT(const BKey_t *k, const uint32_t v)
+{
+  return ((k->val == v) && (k->mod & KMOD_CTRL) && (k->mod & KMOD_SHIFT) && (k->mod & KMOD_ALT));
+}
+
+
+#endif /* __BINIOU_KEYS_H */
