@@ -27,7 +27,7 @@ Layer_new(Plugin_t *p)
 
   l = xcalloc(1, sizeof(Layer_t));
   l->plugin = p;
-  l->mode = NORMAL;
+  l->mode = LM_NORMAL;
 
   return l;
 }
@@ -57,32 +57,36 @@ enum LayerMode
 LayerMode_from_string(const char *mode) {
   if (!strcmp(mode, "none"))
   {
-    return NONE;
+    return LM_NONE;
   }
   if (!strcmp(mode, "normal"))
   {
-    return NORMAL;
+    return LM_NORMAL;
   }
   if (!strcmp(mode, "overlay"))
   {
-    return OVERLAY;
+    return LM_OVERLAY;
   }
   if (!strcmp(mode, "xor"))
   {
-    return XOR;
+    return LM_XOR;
   }
   if (!strcmp(mode, "average"))
   {
-    return AVERAGE;
+    return LM_AVERAGE;
+  }
+  if (!strcmp(mode, "interleave"))
+  {
+    return LM_INTERLEAVE;
   }
   if (!strcmp(mode, "random"))
   {
-    return RANDOM;
+    return LM_RANDOM;
   }
 
   printf("[!] Failed to parse mode '%s', setting to NORMAL\n", mode);
 
-  return NORMAL;
+  return LM_NORMAL;
 }
 
 
@@ -90,30 +94,34 @@ const char *
 LayerMode_to_string(const enum LayerMode mode)
 {
   switch (mode) {
-    case NONE:
+    case LM_NONE:
       return "none";
       break;
 
-    case NORMAL:
+    case LM_NORMAL:
       return "normal";
       break;
 
-    case OVERLAY:
+    case LM_OVERLAY:
       return "overlay";
       break;
 
-    case XOR:
+    case LM_XOR:
       return "xor";
       break;
 
-    case AVERAGE:
+    case LM_AVERAGE:
       return "average";
       break;
 
-    case RANDOM:
+    case LM_RANDOM:
       return "random";
       break;
 
+    case LM_INTERLEAVE:
+      return "interleave";
+      break;
+
     default:
       xerror("LayerMode_to_string: unknown mode= %d\n", mode);
       break;
@@ -126,9 +134,7 @@ LayerMode_to_string(const enum LayerMode mode)
 const char *
 LayerMode_to_OSD_string(const enum LayerMode mode)
 {
-  if ((unsigned)mode > RANDOM) {
-    return "???";
-  } else
-    return
-      &"---\0NOR\0OVL\0XOR\0AVG\0RND\0"[4*mode*sizeof(char)];
+  assert(mode < NB_LAYER_MODES);
+
+  return &"---\0NOR\0OVL\0XOR\0AVG\0ILV\0RND\0"[4 * mode * sizeof(char)];
 }
