@@ -18,7 +18,6 @@
  */
 
 #include "main.h"
-#include "events.h"
 #include "images.h"
 #include "colormaps.h"
 
@@ -28,7 +27,7 @@ char *schemes_file = NULL;
 char *input_plugin = NULL;
 char *output_plugin = NULL;
 char fullscreen = 0;
-long max_fps = 50;
+extern uint8_t max_fps;
 char window_decorations = 1;
 int32_t x_origin = INT32_MIN;
 int32_t y_origin = INT32_MIN;
