@@ -29,7 +29,7 @@ extern char *schemes_file;
 extern char *input_plugin;
 extern char *output_plugin;
 extern char fullscreen;
-extern long max_fps;
+extern uint8_t max_fps;
 extern char window_decorations;
 extern int32_t x_origin;
 extern int32_t y_origin;
@@ -41,7 +41,6 @@ extern enum RandomMode random_mode;
 extern char *pid_file;
 extern char *themes;
 
-
 void register_signals(void);
 void getargs(int, char **);
 void read_keyfile();
