@@ -39,6 +39,7 @@ Porteuse_new(uint32_t size, u_char channel)
   p->size = size;
   p->color = xcalloc(p->size, sizeof(Pixel_t));
   p->trans = xcalloc(size, sizeof(Transform_t));
+  p->connect = xcalloc(size, sizeof(uint8_t));
   p->channel = channel;
 
   for (i = 0; i < size; i++) {
@@ -56,6 +57,7 @@ Porteuse_delete(Porteuse_t *p)
   if (p) {
     xfree(p->color);
     xfree(p->trans);
+    xfree(p->connect);
   }
   xfree(p);
 }
@@ -103,6 +105,8 @@ Porteuse_draw(const Porteuse_t *p, Context_t *ctx, const int connect)
     return;
   }
 
+  assert(p->size <= ctx->input->size);
+
   pthread_mutex_lock(&ctx->input->mutex);
 
   origin = p2d_add(&origin, &t->v_before);
@@ -152,14 +156,14 @@ Porteuse_draw(const Porteuse_t *p, Context_t *ctx, const int connect)
     xi += origin.x;
     yi += origin.y;
 
-    if (connect) {
+    if ((connect == 1) || (connect == 2 && p->connect[i])) {
       draw_line(dst, last.x, last.y, (short)xi, (short)yi, color);
     } else {
-      set_pixel(dst, (short)xi, (short)yi-1, color/2);
-      set_pixel(dst, (short)xi, (short)yi+1, color/2);
-      set_pixel(dst, (short)xi-1, (short)yi, color/2);
-      set_pixel(dst, (short)xi+1, (short)yi, color/2);
-      set_pixel(dst, (short)xi, (short)yi, color);
+      set_pixel(dst, (short)xi,   (short)yi-1, color/2);
+      set_pixel(dst, (short)xi,   (short)yi+1, color/2);
+      set_pixel(dst, (short)xi-1, (short)yi,   color/2);
+      set_pixel(dst, (short)xi+1, (short)yi,   color/2);
+      set_pixel(dst, (short)xi,   (short)yi,   color);
     }
 
     last.x = xi;
