@@ -44,16 +44,18 @@ Particle_delete(Particle_t *p)
 void
 Particle_System_delete(Particle_System_t *ps)
 {
-  GSList *p = ps->particles, *p0 = p;
+  if (NULL != ps) {
+    GSList *p = ps->particles, *p0 = p;
 
-  while (p != NULL) {
-    Particle_t *dp = (Particle_t *)p->data;
-    p = g_slist_next(p);
-    Particle_delete(dp);
+    while (NULL != p) {
+      Particle_t *dp = (Particle_t *)p->data;
+      p = g_slist_next(p);
+      Particle_delete(dp);
+    }
+    g_slist_free(p0);
+
+    xfree(ps);
   }
-  g_slist_free(p0);
-
-  xfree(ps);
 }
 
 
@@ -125,7 +127,7 @@ Particle_System_decay(Particle_System_t *ps)
 
   gettimeofday(&t, NULL);
 
-  while (tmp != NULL) {
+  while (NULL != tmp) {
     float age;
     struct timeval elapsed;
     Particle_t *dp = (Particle_t *)tmp->data;
@@ -160,7 +162,7 @@ Particle_System_move(Particle_System_t *ps)
 {
   GSList *p = ps->particles;
 
-  while (p != NULL) {
+  while (NULL != p) {
     Particle_t *dp = (Particle_t *)p->data;
 
     /* change position */
@@ -194,7 +196,7 @@ Particle_System_draw(const Particle_System_t *ps, const Params3d_t *params3d, Bu
 {
   GSList *p = ps->particles;
 
-  while (p != NULL) {
+  while (NULL != p) {
     Particle_t *dp = (Particle_t *)p->data;
     set_pixel_3d(params3d, dst, &dp->pos, dp->col.idx);
     p = g_slist_next(p);
