@@ -44,6 +44,7 @@ Plugin_load(Plugin_t *p)
 {
   const char *error = NULL;
   u_long *_tmp;
+  enum LayerMode *_mode;
 
   assert(NULL != p);
 
@@ -78,8 +79,8 @@ Plugin_load(Plugin_t *p)
     p->options = _tmp;
   }
 
-  _tmp = (u_long *) dlsym(p->handle, "mode");
-  p->mode = _tmp;
+  _mode = (enum LayerMode *) dlsym(p->handle, "mode");
+  p->mode = _mode;
 
   /* get display name */
   p->dname = (char *) dlsym(p->handle, "dname");
