@@ -26,6 +26,7 @@
 #define PLUGIN_PARAMETER_CHANGED 2
 
 enum PluginType { PL_INPUT, PL_MAIN, PL_OUTPUT };
+enum LayerMode { LM_NONE = 0, LM_NORMAL, LM_OVERLAY, LM_XOR, LM_AVERAGE, LM_INTERLEAVE, LM_RANDOM, NB_LAYER_MODES };
 
 struct Context_s;
 
@@ -34,7 +35,7 @@ typedef struct Plugin_s {
 
   uint32_t version; /* version to increase when exposed parameters change */
   u_long *options;
-  u_long *mode;
+  enum LayerMode *mode;
 
   char   *name;
   char   *file;     /* to unload/reload */
