@@ -30,11 +30,11 @@ blacklisted(const char *name)
 {
   gchar **p = blacklist;
 
-  if (p == NULL) {
+  if (NULL == p) {
     return 0;
   }
 
-  while (*p != NULL) {
+  while (NULL != *p) {
     if (!strcmp(name, *p)) {
 #ifdef DEBUG
       printf("[+] %s is blacklisted\n", name);
@@ -123,7 +123,7 @@ Plugins_init(Plugins_t *ps)
     uint16_t idx = 0;
 
     for (i = 0; i < old_size; i++) {
-      if (ps->plugins[i] != NULL) {
+      if (NULL != ps->plugins[i]) {
         res[idx++] = ps->plugins[i];
       }
     }
@@ -204,12 +204,12 @@ Plugins_load(Plugins_t *ps, const Context_t *ctx)
   blah = g_strdup_printf("%s/main", ps->path);
   VERBOSE(printf("[i] Loading plugins from %s\n", blah));
 
-  if ((da_dir = opendir(blah)) == NULL) {
+  if (NULL == (da_dir = opendir(blah))) {
     xperror("opendir");
   }
 
   g_free(blah);
-  while ((da_ent = readdir(da_dir)) != NULL)
+  while (NULL != (da_ent = readdir(da_dir)))
     if (isPluginDir(ps->path, da_ent->d_name)) {
       ps->size++;
     }
@@ -223,10 +223,9 @@ Plugins_load(Plugins_t *ps, const Context_t *ctx)
   rewinddir(da_dir);
   i = 0;
 
-  while ((da_ent = readdir(da_dir)) != NULL) {
+  while (NULL != (da_ent = readdir(da_dir))) {
     Plugin_t *p;
     u_char t;
-    int j;
     const char *name = da_ent->d_name;
 
     if (!isPluginDir(ps->path, name)) {
@@ -246,13 +245,13 @@ Plugins_load(Plugins_t *ps, const Context_t *ctx)
     p = ps->plugins[i] = Plugin_new(ps->path, name, PL_MAIN);
     if (NULL != p) {
       if (
-        ((ctx->input != NULL) ||
-         ((ctx->input == NULL) && (!(*p->options & BE_SFX2D) && !(*p->options & BE_SFX3D))))
+        ((NULL != ctx->input) ||
+         ((NULL == ctx->input) && (!(*p->options & BE_SFX2D) && !(*p->options & BE_SFX3D))))
         // check if plugin needs input
         &&
         // check if plugin needs images
-        ((ctx->imgf != NULL) ||
-         ((ctx->imgf == NULL) && (!(*p->options & BEQ_IMAGE))))
+        ((NULL != ctx->imgf) ||
+         ((NULL == ctx->imgf) && (!(*p->options & BEQ_IMAGE))))
         &&
         // check if plugin needs webcam
         ((ctx->webcams > 0) ||
@@ -265,10 +264,7 @@ Plugins_load(Plugins_t *ps, const Context_t *ctx)
             printf("!!! FIXME: %s has no description\n", name);
           }
         }
-        for (j = 0; j < i; j++)
-          if (p->id == ps->plugins[j]->id) {
-            xerror("Duplicated plugin id: %li\n", p->id);
-          }
+
         /* plugin types stuff */
         for (t = 0; t < MAX_TYPES; t++)
           if (*p->options & (1 << t)) {
@@ -282,6 +278,7 @@ Plugins_load(Plugins_t *ps, const Context_t *ctx)
 #endif
         i++;
       } else {
+        VERBOSE(printf("\n"));
         ps->plugins[i] = NULL;
         Plugin_delete(p);
         ps->size--;
@@ -295,7 +292,7 @@ Plugins_load(Plugins_t *ps, const Context_t *ctx)
   Plugin_t **res = xcalloc(ps->size, sizeof(Plugin_t *));
   int idx = 0;
   for (i = 0; i < old_size; i++) {
-    if (ps->plugins[i] != NULL) {
+    if (NULL != ps->plugins[i]) {
       res[idx++] = ps->plugins[i];
     }
   }
@@ -315,21 +312,7 @@ Plugins_load(Plugins_t *ps, const Context_t *ctx)
 
 
 Plugin_t *
-Plugins_find(const u_long id)
-{
-  short i;
-
-  for (i = 0; i < plugins->size; i++)
-    if (plugins->plugins[i]->id == id) {
-      return plugins->plugins[i];
-    }
-
-  return NULL;
-}
-
-
-Plugin_t *
-Plugins_find_by_name(const char *name)
+Plugins_find(const char *name)
 {
   short i;
 
@@ -362,7 +345,7 @@ Plugins_get_random(const enum PluginOptions feat, const Plugin_t *locked)
   }
   // else printf("pTypes[%d].count= %d\n", i, pTypes[i].count);
 
-  uint8_t ignore_beq_norandom = (getenv("LEBINIOU_IGNORE_BEQ_NORANDOM") != NULL);
+  uint8_t ignore_beq_norandom = (NULL != getenv("LEBINIOU_IGNORE_BEQ_NORANDOM"));
 
   int retry;
   do {
@@ -426,19 +409,6 @@ Plugins_prev_n(const u_short n)
 }
 
 
-void
-Plugins_change_run_callback(const u_long id, void (*run)(struct Context_s *))
-{
-  Plugin_t *p = NULL;
-
-  p = Plugins_find(id);
-
-  if (p != NULL) {
-    p->run = run;
-  }
-}
-
-
 void
 Plugins_reload_selected(Plugins_t *plugins)
 {
