@@ -21,8 +21,10 @@
 #define __BINIOU_PLUGINS_H
 
 #include "plugin.h"
-#include "event.h"
+#include "commands.h"
 #include "context.h"
+#include "cmapfader.h"
+#include "imagefader.h"
 
 
 typedef struct Plugins_s {
@@ -51,7 +53,7 @@ void Plugins_prev();
 void Plugins_next_n(const u_short);
 void Plugins_prev_n(const u_short);
 
-int Plugins_event(Plugins_t *, const Event_t *);
+void Plugins_command(Plugins_t *, const enum Command);
 
 void Plugins_set_blacklist(gchar **);
 
