@@ -144,7 +144,7 @@ Schemes_parse_option(const char *opt) {
   int o = 0;
   char *pipe = NULL;
 
-  while ((pipe = strchr(opt, '|')) != NULL)
+  while (NULL != (pipe = strchr(opt, '|')))
   {
     *pipe = '\0';
     if (*opt == '-') {
@@ -178,12 +178,12 @@ Schemes_parse(Schemes_t *schemes, const xmlDocPtr doc)
 
   /* Start at Root Element */
   schemes_node = xmlDocGetRootElement(doc);
-  if (schemes_node == NULL) {
+  if (NULL == schemes_node) {
     xerror("xmlDocGetRootElement error\n");
   }
 
   schemes_node = xmlFindElement("schemes", schemes_node);
-  if (schemes_node == NULL) {
+  if (NULL == schemes_node) {
     printf("[!] No <schemes> found\n");
     return 0;
   }
@@ -201,7 +201,7 @@ Schemes_parse(Schemes_t *schemes, const xmlDocPtr doc)
     xmlNodePtr type_node = NULL;
 
     scheme_node = xmlFindElement("scheme", scheme_node);
-    if (scheme_node == NULL) {
+    if (NULL == scheme_node) {
       printf("[!] No <scheme> found\n");
       return 0;
     }
@@ -222,7 +222,7 @@ Schemes_parse(Schemes_t *schemes, const xmlDocPtr doc)
       xmlChar *token;
 
       type_node = xmlFindElement("type", type_node);
-      if (type_node == NULL) {
+      if (NULL == type_node) {
         int k;
 
         printf("[!] No <type> found\n");
@@ -242,7 +242,7 @@ Schemes_parse(Schemes_t *schemes, const xmlDocPtr doc)
       }
 
       token = xmlNodeListGetString(doc, type_node->xmlChildrenNode, 1);
-      if (token == NULL) {
+      if (NULL == token) {
         xerror("No data in <type> element\n");
       }
 
@@ -280,7 +280,7 @@ Schemes_new(const char *file)
    * build an XML tree from the file
    */
   doc = xmlParseFile(file);
-  if (doc == NULL) {
+  if (NULL == doc) {
     printf("[!] xmlParseFile '%s' error\n", file);
     printf("[!] No schemes loaded\n");
     xfree(schemes);
@@ -327,7 +327,7 @@ Schemes_new_default()
 void
 Schemes_delete()
 {
-  if (schemes != NULL) {
+  if (NULL != schemes) {
     u_short i;
 
     for (i = 0; i < schemes->size; i++) {
