@@ -40,9 +40,6 @@ Schemes_random(Context_t *ctx)
 
   do {
     int i;
-    struct timeval t;
-
-    gettimeofday(&t, NULL);
 
     ok = 1;
     if ((NULL != schemes->shuffler) && !Shuffler_ok(schemes->shuffler)) {
@@ -50,14 +47,14 @@ Schemes_random(Context_t *ctx)
       return;
     }
 
-    Sequence_clear(new, t.tv_sec);
+    Sequence_clear(new, 0);
 
     random = (NULL != schemes->shuffler) ? Shuffler_get(schemes->shuffler) : 0;
     for (i = 0; ok && schemes->schemes[random][i].type; i++) {
       /* check if we should insert a lens or a normal plugin */
       if (drand48() <= schemes->schemes[random][i].p) {
         const int not_lens = ((short)schemes->schemes[random][i].type < 0) ? 1 : 0;
-        const int res = Context_add_rand(new, (enum PluginOptions)(schemes->schemes[random][i].type), not_lens, ctx->locked);
+        const int res = Context_add_rand(new, (enum PluginOptions)(schemes->schemes[random][i].type), not_lens, ctx->locked, 1);
 
         /* if ((res == -1) && (schemes->schemes[random][i].p == 1.0)) { */
         /* this is the correct way to check with floats: */
