@@ -396,7 +396,7 @@ bare_sequence:
       mode = LayerMode_from_string((const char *)youhou);
       xmlFree(youhou);
     } else {
-      mode = NORMAL;
+      mode = LM_NORMAL;
     }
     layer->mode = mode;
 
