@@ -91,7 +91,7 @@ Sequence_write_json(const Sequence_t *s, const char *filename, const uint8_t ful
 
 
 void
-Sequence_save(Context_t *ctx, Sequence_t *s, int overwrite, const int is_transient,
+Sequence_save(Context_t *ctx, Sequence_t *s, int overwrite,
               const uint8_t bare, const char auto_colormaps, const char auto_images)
 {
   Sequence_t *store = NULL;
@@ -114,7 +114,7 @@ Sequence_save(Context_t *ctx, Sequence_t *s, int overwrite, const int is_transie
   uint32_t old_id = s->id; // to restore if Sequence_write_json() fails
   char *old_name = (NULL != s->name) ? strdup(s->name) : NULL; // ditto
 
-  if (!overwrite || is_transient) {
+  if (!overwrite) {
     xfree(s->name);
     s->id = unix_timestamp();
   }
