@@ -20,15 +20,14 @@
 #ifndef __BINIOU_SEQUENCE_MANAGER_H
 #define __BINIOU_SEQUENCE_MANAGER_H
 
+#include "context.h"
 #include "sequence.h"
-#include "event.h"
+#include "commands.h"
 #include "constants.h"
 
 
-enum BankMode { SEQUENCES=0, COLORMAPS, IMAGES };
-
 typedef struct SequenceManager_s {
-  Sequence_t      *cur, *next, *transient;
+  Sequence_t      *cur, *next;
   GList           *curseq;
   pthread_mutex_t mutex;
 } SequenceManager_t;
@@ -49,9 +48,7 @@ void SequenceManager_default_layer_mode(const Sequence_t *);
 void SequenceManager_prev_layer_mode(const Sequence_t *);
 void SequenceManager_next_layer_mode(const Sequence_t *);
 
-int SequenceManager_event(struct Context_s *, const Event_t *, const char, const char);
-
-int SequenceManager_is_transient(const SequenceManager_t *, const Sequence_t *);
+void SequenceManager_command(struct Context_s *, const enum Command, const char, const char);
 
 void SequenceManager_lock(SequenceManager_t *);
 void SequenceManager_unlock(SequenceManager_t *);
