@@ -34,7 +34,7 @@ typedef struct Sequences_s {
 void Sequences_new();
 void Sequences_free();
 
-Sequence_t *Sequences_find(const uint32_t);
+GList *Sequences_find(const uint32_t);
 
 void Sequences_set_dir(char *);
 const char *Sequences_get_dir();
