@@ -23,7 +23,7 @@
 #include "utils.h"
 
 
-enum ShufflerMode { BS_NONE=0, BS_SHUFFLE, BS_CYCLE, BS_RANDOM } ShufflerMode_e;
+enum ShufflerMode { BS_NONE=0, BS_SHUFFLE, BS_CYCLE, BS_RANDOM };
 
 
 typedef struct Shuffler_s {
