@@ -45,7 +45,7 @@ Translation_new(Map_t (*f)(const short, const short), void (*init)())
 {
   Translation_t *t = NULL;
 
-  assert(init != NULL);
+  assert(NULL != init);
 
   t = xcalloc(1, sizeof(Translation_t));
   t->f = f;
@@ -117,7 +117,7 @@ Translation_compute(Translation_t *t)
 {
   u_short k;
 
-  assert(t != NULL);
+  assert(NULL != t);
   for (k = 0; (k < BATCH_LINES) && !Translation_batch_done(t); k++)
     if (Translation_batch_line(t)) {
       return;
@@ -145,7 +145,7 @@ Translation_run(Translation_t *t, const Context_t *ctx)
 void
 Translation_delete(Translation_t *t)
 {
-  if (t != NULL) {
+  if (NULL != t) {
     xfree(t->point);
     xfree(t);
   }
