@@ -145,7 +145,7 @@ rmkdir(const char *p)
   char *slash = NULL;
   char *path;
 
-  assert(p != NULL);
+  assert(NULL != p);
   path = strdup(p);
 
   if (path[0] == '/') {
@@ -154,7 +154,7 @@ rmkdir(const char *p)
     slash = strchr(path, '/');
   }
 
-  while (slash != NULL) {
+  while (NULL != slash) {
     *slash = '\0';
     rmkdir2(path);
     *slash = '/';
@@ -259,7 +259,7 @@ parse_two_shorts(const char *str, const int delim, short *a, short *b)
 int
 check_command(const char *cmd)
 {
-  if (cmd != NULL) {
+  if (NULL != cmd) {
     int res = system(cmd);
     if (!res) {
       return 0;
